<?php

$locale["  %d%% (%d/%d)"] =
   "  %d%% (%d/%d)";
$locale[" ... around %s"] =
   "... 包圍 %s";
$locale[" ... first %d bytes"] =
   " ... 頭 %d bytes";
$locale[" ... first %d lines"] =
   " ... 頭 %d 列";
$locale[" Additionally, try to keep the latest contributions of all authors in the last %d days (even if there are more than %d of them,) but in no case keep more than %d unique author revisions."] =
   " 除此之外, 試著保存最近 %d 天之內所有作者的最新貢獻 (即使超過他們的 %d ,) 但是沒保存超過 %d 份單一作者修訂.";
$locale[" Keep the latest contributions of the last %d authors up to %d days."] =
   "保存最後 %d 位作者的最新貢獻直到 %d 天.";
$locale[" Keep up to %d minor edits, but keep them no longer than %d days."] =
   "保持 %d 份次要編輯,但不超過 %d 天.";
$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%d UserPreferences fields successfully updated."] =
   "%d UserPreference 欄位已成功地更新.";
$locale["%d homepages"] =
   "%d 個主頁";
$locale["%d minutes"] =
   "%d 分鐘";
$locale["%d not-empty pages"] =
   "%d 個非空白頁面";
$locale["%d online users"] =
   "%d 位使用者正在線上";
$locale["%d page(s) with more than %d hits (>%d%%)."] =
   "%d 個頁面超過 %d 個擊閱數(>%d%%).";
$locale["%d pages"] =
   "%d 個頁面";
$locale["%d pages with less than %d hits (<%d%%)."] =
   "%d 個頁面少於 %d 個擊閱數(<%d%%).";
$locale["%s Kb (%s bytes)"] =
   "%s Kb (%s bytes)";
$locale["%s already exists"] =
   "%s 已經存在";
$locale["%s at %s"] =
   "%s 在 %s";
$locale["%s b"] =
   "%s b";
$locale["%s by %s"] =
   "%s 被 %s";
$locale["%s bytes"] =
   "%s bytes";
$locale["%s bytes written"] =
   "已寫入 %s bytes";
$locale["%s days"] =
   "%s 天";
$locale["%s does not appear to be a WikiPlugin."] =
   "%s 看起來不是 WikiPlugin.";
$locale["%s does not know about the language '%s', using 'en' instead."] =
   "%s 不認識此語言 '%s', 使用 'en' 代替.";
$locale["%s is disallowed on this wiki."] =
   "在此 wiki 上, %s 是被禁止的.";
$locale["%s is empty"] =
   "%s 是空白";
$locale["%s is empty."] =
   "%s 是空白的.";
$locale["%s is not writable."] =
   "%s 無法寫入.";
$locale["%s is only allowed in locked pages."] =
   "%s 只允許在鎖定的頁面中.";
$locale["%s k"] =
   "%s k";
$locale["%s not found"] =
   "%s 找不到.";
$locale["%s of this page"] =
   "此頁面的 %s";
$locale["%s or %s parameter missing"] =
   "%s 或 %s 參數遺漏";
$locale["%s pages changed."] =
   "%s 個頁面已經變更.";
$locale["%s pages have been changed."] =
   "%s 頁面已經變更.";
$locale["%s pages have been permanently renamed."] =
   "%s pages 已經永久更名了.";
$locale["%s pages link to %s:"] =
   "%s 個頁面連結到 %s:";
$locale["%s pages would link to %s:"] =
   "%s 個頁面可能連結到 %s:";
$locale["%s parameter missing"] =
   "%s 參數遺漏";
$locale["%s prediction for you is %.1f stars"] =
   "%s 對你的預測有 %.1f 星";
$locale["%s prediction for you is %s stars"] =
   "%s 對你的預測有 %s 星.";
$locale["%s words"] =
   "共 %s 字";
$locale["%s(%d): no such revision"] =
   "%s(%d): 沒有這個修訂.";
$locale["%s: %s"] =
   "%s: %s";
$locale["%s: Bad action"] =
   "%s: 錯誤的動作";
$locale["%s: Can't open dba database"] =
   "%s: 無法開啟 dba 資料庫";
$locale["%s: Date of new revision is %s"] =
   "%s: 新版本的日期是 %s";
$locale["%s: argument index out of range"] =
   "%s: 引數索引超出範圍";
$locale["%s: error while handling error:"] =
   "%s: 處理錯誤時發生錯誤";
$locale["%s: file not found"] =
   "%s: 找不到檔案.";
$locale["%s: no such class"] =
   "%s: 無此類別";
$locale["%s: not defined"] =
   "%s: 未被定義";
$locale["'%s': Bad page name"] =
   "'%s': 錯誤的頁面名稱";
$locale["'%s': Bad page name: %s"] =
   "'%s': 錯誤頁面名稱: %s";
$locale["'%s': corrupt file"] =
   "'%s': 壞檔";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] =
   "(複製你的更動到剪貼簿中. 你可以試著編輯另一個不同的頁面或存到文字編輯器中.)";
$locale["(Pages which have been deleted at least %s days are already checked.)"] =
   "(列出過去 %s 天內已被刪除且檢查過的頁面.)";
$locale["(Redirected from %s)"] =
   "(已從 %s 重導向)";
$locale["(User: %s)"] =
   "(user: %s)";
$locale["(Your preferences are stored as hidden data within this page)."] =
   "(你的偏好設定已經存放並隱藏在此頁面中).";
$locale["(diff)"] =
   "(差異)";
$locale["(disable individual page permissions, enable inheritance)?"] =
   "(禁制個別網頁的權限,使用繼承)?";
$locale["(max. recursion level: %d)"] =
   "(最大遞迴層級: %d)";
$locale["(ugo : rwx)"] =
   "(ugo : rwx)";
$locale["- saved to database as version %d"] =
   "- 已經以版本 %d 存入資料庫中";
$locale["-???"] =
   "-???";
$locale["... copied to %s"] =
   "... 複製到 %s";
$locale["... not found"] =
   "... 沒找到";
$locale["1 day"] =
   "1 天";
$locale["1 word"] =
   "1 個單字";
$locale["<%s: no such section>"] =
   "<%s: 沒有此部份>";
$locale["<empty>"] =
   "<空白>";
$locale["<no matches>"] =
   "<沒有相符>";
$locale["<none>"] =
   "<無>";
$locale["<not displayed>"] =
   "<未能顯示>";
$locale["<system language>"] =
   "<系統語言>";
$locale["<system theme>"] =
   "<系統佈景主題>";
$locale["<unknown>"] =
   "<未知的>";
$locale["A plugin to provide for raw HTML within wiki pages."] =
   "用來在 wiki 頁面提供 raw HTML的 plugin.";
$locale["A required argument '%s' is missing."] =
   "缺少引數 '%s'.";
$locale["ACCESS DENIED: You must log in to upload files."] =
   "拒絕存取: 請先登入才能上傳檔案";
$locale["ACL"] =
   "ACL";
$locale["Action page"] =
   "動作頁面";
$locale["Add %s hours to the server's local time when reporting times."] =
   "當回報時間時,在伺服器的本地時間加上 %s 個小時.";
$locale["Add a Comment"] =
   "加入意見";
$locale["AddComment"] =
   "AddComment";
$locale["AddCommentPlugin"] =
   "AddCommentPlugin";
$locale["AddingPages"] =
   "AddingPages";
$locale["Adjust"] =
   "調整";
$locale["Admin"] =
   "管理者";
$locale["Admin is also online."] =
   "Admin 也在線上.";
$locale["Administrators"] =
   "管理者";
$locale["All %s are listed below."] =
   "所有 %s 已被列在下面.";
$locale["AllPages"] =
   "AllPages";
$locale["AllUsers"] =
   "AllUsers";
$locale["Allowed protocols"] =
   "允許的協定";
$locale["Allows selection of multiple pages which get passed to other WikiAdmin plugins."] =
   "允許選擇多個已傳遞的頁面到其他 WikiAdmin plugin.";
$locale["Also pages which have been deleted at least %s days."] =
   "也列出過去 %s 天被刪除的頁面.";
$locale["An unnamed PhpWiki"] =
   "未被命名的 PhpWiki";
$locale["Anonymous Users"] =
   "Anonymous 使用者";
$locale["Appearance"] =
   "Appearance";
$locale["Application name"] =
   "應用程式名稱";
$locale["Application size: %d Kb"] =
   "應用程式大小: %d Kb";
$locale["Are you sure you want to permanently change the selected files?"] =
   "你確定你想要永久變更選定的檔案?";
$locale["Are you sure you want to permanently remove the selected files?"] =
   "你確定你想要永久移除選定的檔案?";
$locale["Are you sure you want to permanently rename the selected files?"] =
   "你確定你想要永久更名選定的檔案?";
$locale["Are you sure you want to permanently search & replace text in the selected files?"] =
   "你確定你想要永久新增並取代選定檔案中的文字?";
$locale["Arguments"] =
   "引數";
$locale["Attempting to use the directory '%s' instead."] =
   "試圖改用目錄 '%s'.";
$locale["Auth Level"] =
   "認證層級";
$locale["Auth Method"] =
   "認證方式";
$locale["Authenticated Users"] =
   "已認證的使用者";
$locale["Authenticated as %s"] =
   "認證為 %s";
$locale["Authenticated users on this wiki (%d total):"] =
   "在此 wiki 上被確認的使用者 (共 %d):";
$locale["Author"] =
   "作者";
$locale["Author will be logged as %s."] =
   "作者將登入為 %s.";
$locale["AuthorHistory"] =
   "作者歷程";
$locale["AuthorHistoryPlugin"] =
   "AuthorHistoryPlugin";
$locale["Automatically link headers at the top"] =
   "在上面自動連結表頭";
$locale["Available plugins"] =
   "可用的 plugin";
$locale["BAD URL -- remove all of <, >, \""] =
   "錯誤 URL -- 移除所有的 <, >, \"";
$locale["BAD phpwiki: URL"] =
   "錯誤 phpwiki: URL";
$locale["BackLinks"] =
   "BackLinks";
$locale["BackLinks for %s"] =
   "向後連結: %s";
$locale["Bad Version"] =
   "錯誤的版本";
$locale["Bad file type: %s"] =
   "錯誤的檔案型態: %s";
$locale["Bad url in src: remove all of <, >, \""] =
   "在 src 中錯誤的 url: 移除所有的 <, .>, \"";
$locale["Blog page"] =
   "Blog 頁面";
$locale["Bogo Users"] =
   "Bogo 使用者";
$locale["Browsing pages"] =
   "瀏覽頁面";
$locale["Cache statistics"] =
   "快取統計";
$locale["Calendar"] =
   "月曆";
$locale["CalendarList"] =
   "月曆列表";
$locale["CalendarListPlugin"] =
   "CalendarListPlugin";
$locale["CalendarPlugin"] =
   "CalendarPlugin";
$locale["Can't inflate data: zlib support not enabled in this PHP"] =
   "無法壓縮資料: 此 PHP 的 zlib 支援未被啟動";
$locale["Can't mix '%s' with '%s' type format strings"] =
   "無法混合 '%s' 和 '%s' 型態的格式字串.";
$locale["Can't open zip file '%s' for reading"] =
   "無法開啟 zip 檔案 '%s' 進行讀取";
$locale["Cancel"] =
   "取消";
$locale["Cancel rating"] =
   "取消評比";
$locale["Cannot create directory '%s'"] =
   "無法建立目錄 '%s'";
$locale["Cannot open AUTH_GROUP_FILE %s"] =
   "無法開啟 AUTH_GROUP_FILE %s";
$locale["CategoryCategory"] =
   "CategoryCategory";
$locale["CategoryGroup"] =
   "CategoryGroup";
$locale["CategoryHomePages"] =
   "CategoryHomePages";
$locale["CategoryHomepage"] =
   "分類首頁";
$locale["CategoryPage"] =
   "CategoryPage";
$locale["Change Password"] =
   "改變密碼";
$locale["Change Verification Status"] =
   "改變確認狀態";
$locale["Change country"] =
   "變更國家";
$locale["Change page attributes"] =
   "變更頁面屬性";
$locale["Change pagename in all linked pages also?"] =
   "也在所有連結到的頁面裡變更頁面名稱?";
$locale["Check any two boxes then %s."] =
   "任找兩個空格打勾然後 %s.";
$locale["Check any two boxes to compare revisions."] =
   "任找兩個空格打勾以進行比較修訂.";
$locale["Chmod"] =
   "Chmod";
$locale["Chmod to permission:"] =
   "改變權限為:";
$locale["Click to authenticate as %s"] =
   "點擊以 %s 進行驗證.";
$locale["Click to de-/select all pages"] =
   "點擊以取消選擇或選擇所有頁面";
$locale["Click to display"] =
   "點擊以顯示";
$locale["Click to reverse sort order"] =
   "點擊以反轉排列順序";
$locale["Click to sort by %s"] =
   "點擊以 %s 排序";
$locale["Columns: %s."] =
   "行: %s.";
$locale["Comment"] =
   "意見";
$locale["Comment modified on %s by %s"] =
   "意見在 %s 被 %s 變更";
$locale["CommentPlugin"] =
   "CommentPlugin";
$locale["Comments"] =
   "意見";
$locale["Complete."] =
   "完成";
$locale["Conflicting Edits!"] =
   "發生衝突!";
$locale["Content"] =
   "內容";
$locale["Contents"] =
   "內容";
$locale["ContributedTranslations"] =
   "ContributedTranslations";
$locale["Control characters not allowed"] =
   "控制字元是不被允許的";
$locale["Convert text into a png image using GD."] =
   "使用 GD 轉換文字為 png 圖片";
$locale["Converts TeX to an image. May be used to embed formulas in PhpWiki."] =
   "轉換 TeX 為圖片. 可以用來在 PhpWiki 嵌入方程式.";
$locale["Couldn't chmod page '%s' to '%s'."] =
   "無法為頁面 '%s' 變更權限為 '%s'.";
$locale["Couldn't rename page '%s' to '%s'."] =
   "無法更名頁面 '%s' 為 '%s'.";
$locale["Create a Wiki page by the provided name."] =
   "以提供的名稱建立 Wiki 頁面.";
$locale["Create a Wiki page."] =
   "建立 Wiki 頁面";
$locale["Create a new (sub)page"] =
   "建立新(子)頁面";
$locale["Create: %s"] =
   "建立: %s";
$locale["CreatePage"] =
   "CreatePage";
$locale["CreateToc"] =
   "CreateToc";
$locale["CreateTocPlugin"] =
   "CreateTocPlugin";
$locale["Created by CreatePage"] =
   "由 CreatePage 建立";
$locale["Created directory '%s' for the page dump..."] =
   "為頁面傾印建立目錄 '%s'...";
$locale["Creating pages"] =
   "建立頁面";
$locale["Creator"] =
   "建立者";
$locale["Current Language"] =
   "目前語言";
$locale["Current Theme"] =
   "目前佈景主題";
$locale["Current language: '%s'"] =
   "目前語言: '%s'";
$locale["Current theme: '%s'"] =
   "目前佈景主題: '%s'";
$locale["Currently not recommended!"] =
   "現在不建議使用!";
$locale["Database"] =
   "資料庫";
$locale["Date Format"] =
   "日期格式";
$locale["DebugInfo"] =
   "DebugInfo";
$locale["Default InterWiki map file not loaded."] =
   "預設 InterWiki map 檔案未能載入.";
$locale["Default language: '%s'"] =
   "預設語言: '%s'";
$locale["Default preferences will be used."] =
   "預設偏好設定將被使用.";
$locale["Default theme: '%s'"] =
   "預設佈景主題: '%s'";
$locale["Define a translation for a specified text"] =
   "為特定文字定義轉換.";
$locale["Define the translation for %s in %s"] =
   "為 %s 定義轉換,在 %s";
$locale["Deleted %s pages with invalid names:"] =
   "刪除 %s 個錯誤名稱的頁面:";
$locale["Describe %s here."] =
   "在這兒描述 %s.";
$locale["Description"] =
   "描述";
$locale["Description: Provides a list of plugins on this wiki."] =
   "描述: 提供在此 wiki 上的 plugin 列表.";
$locale["Dialog"] =
   "對話盒";
$locale["Diff"] =
   "差異";
$locale["Diff previous Author"] =
   "與上個作者做比對";
$locale["Diff previous Revision"] =
   "與上個修訂做比對";
$locale["Diff: %s"] =
   "差異: %s";
$locale["Differences between %s and %s of %s."] =
   "在 %s 與 %s 間的差異 - %s.";
$locale["Diffing pages"] =
   "比對頁面差異";
$locale["Display arbitrary SQL result tables"] =
   "顯示不受限制的 SQL 結果表格";
$locale["Display differences between revisions"] =
   "顯示修訂間的差異";
$locale["Display general and user specific auth information."] =
   "顯示一般與使用者特定認證資訊.";
$locale["Displays a list of randomly chosen pages or redirects to a random page."] =
   "顯示隨機選出的頁面列表或重導向到隨機選取的頁面.";
$locale["Displays a set of photos listed in a text file with optional descriptions"] =
   "顯示帶有簡單描述的文字檔內的相片集合";
$locale["Displays a url in a seperate frame inside our body. Only one frame allowed."] =
   "在內容的分離框架中顯示 url. 只能放一個框架.";
$locale["Don't cache this page."] =
   "不要快取此頁面.";
$locale["Double redirect not allowed."] =
   "雙重重導向是不允許的.";
$locale["Download for CVS"] =
   "給 CVS 的下載";
$locale["Download for backup"] =
   "給備份用的下載";
$locale["Download the page contents"] =
   "下載頁面內容";
$locale["Downloading html zip dumps"] =
   "下載 html zip dumps";
$locale["Downloading zip dumps"] =
   "下載 zip dumps";
$locale["Dump Pages"] =
   "傾印頁面";
$locale["Dump Pages as XHTML"] =
   "傾印頁面為 XHTML";
$locale["Dumping Pages"] =
   "傾印頁面中";
$locale["Dumping html pages"] =
   "傾印 html 頁面";
$locale["Dumping serial pages"] =
   "傾印連續頁面";
$locale["E-Mail"] =
   "E-Mail";
$locale["E-mail"] =
   "E-mail";
$locale["Easy navigation buttons for %s"] =
   "簡單的巡覽按鈕 - %s";
$locale["Edit"] =
   "編輯";
$locale["Edit %s"] =
   "編輯 %s";
$locale["Edit Area Size"] =
   "編輯區域大小";
$locale["Edit Old Revision"] =
   "編輯舊的修訂";
$locale["Edit aborted."] =
   "編輯中止.";
$locale["Edit metadata for %s"] =
   "為 %s 編輯中繼資料";
$locale["Edit old revision"] =
   "編輯舊修訂";
$locale["Edit this page"] =
   "編輯此頁面";
$locale["Edit this page and all subpages"] =
   "編輯此頁面以及所有子頁面";
$locale["Edit: %s"] =
   "編輯: %s";
$locale["EditMetaData"] =
   "編輯中繼資料";
$locale["EditMetaDataPlugin"] =
   "EditMetaDataPlugin";
$locale["EditText"] =
   "EditText";
$locale["Edited by: %s"] =
   "由 %s 編輯";
$locale["Editing pages"] =
   "編輯頁面";
$locale["Elapsed time: %s s"] =
   "經過時間: %s s";
$locale["Email Verification"] =
   "Email 驗證.";
$locale["Email not yet verified."] =
   "Email 尚未被驗證.";
$locale["Email verified."] =
   "Email 已被驗證.";
$locale["Embed hidden comments in WikiPages."] =
   "在 Wiki頁面嵌入隱藏意見.";
$locale["Empty Preferences or format of UserPreferences cookie not recognised."] =
   "空的偏好設定或 UserPreferences cookie 格式無法辨認.";
$locale["Empty link to: %s"] =
   "沒有連結到: %s";
$locale["Empty pagename!"] =
   "空白的頁面名稱!";
$locale["Enable configurable polls"] =
   "啟動設定好的投票";
$locale["Enter pages seperated by space or comma. Wildcards (fileglobbing) allowed."] =
   "輸入頁面並以空白或逗號分隔.允許使用萬用字元 (fileglobbing).";
$locale["Enter your UserId to sign in"] =
   "輸入你的帳號進行簽入";
$locale["Error: Empty search string."] =
   "錯誤: 空白的搜尋字串.";
$locale["Error: The user HomePage must be a valid WikiWord. Sorry, UserPreferences cannot be saved."] =
   "錯誤: 使用者的首頁必須是一個合法的 WikiWord. 抱歉, UserPreferences 無法儲存.";
$locale["Every"] =
   "每";
$locale["Expiry parameters"] =
   "過期參數";
$locale["External Links"] =
   "外部連結";
$locale["ExternalSearch"] =
   "外部搜尋";
$locale["ExternalSearchPlugin"] =
   "ExternalSearchPlugin";
$locale["Fatal PhpWiki Error"] =
   "致命的 PhpWiki 錯誤";
$locale["File successfully uploaded."] =
   "檔案已經成功地上傳.";
$locale["FindPage"] =
   "FindPage";
$locale["First"] =
   "開頭";
$locale["FrameInclude"] =
   "FrameInclude";
$locale["FrameIncludePlugin"] =
   "FrameIncludePlugin";
$locale["From english to %s: "] =
   "從英文到 %s:";
$locale["Full Search"] =
   "完整搜尋";
$locale["Full text search results for '%s'"] =
   "以 '%s' 全文搜尋的結果";
$locale["FullDump"] =
   "完整傾印";
$locale["FullRecentChanges"] =
   "FullRecentChanges";
$locale["FullTextSearch"] =
   "FullTextSearch";
$locale["FuzzyPages"] =
   "FuzzyPages";
$locale["General Auth Settings"] =
   "一般認證設定";
$locale["Get an email notification at changes of the following pages:"] =
   "在變更下列頁面時取得 email 通知:";
$locale["Get debugging information for %s."] =
   "為 %s 取得除錯資訊.";
$locale["Get preferences information for current user %s."] =
   "為目前使用者 %s 取得偏好設定資訊.";
$locale["Go"] =
   "Go";
$locale["Go to or create page."] =
   "前往或建立頁面.";
$locale["GoTo"] =
   "GoTo";
$locale["GooglePlugin"] =
   "GooglePlugin";
$locale["Group %s does not exist"] =
   "群組 %s 不存在";
$locale["Guest"] =
   "訪客";
$locale["Guests"] =
   "訪客";
$locale["H"] =
   "高";
$locale["HasHomePage"] =
   "HasHomePage";
$locale["Height"] =
   "高度";
$locale["HelloWorld"] =
   "HelloWorld";
$locale["HelloWorldPlugin"] =
   "HelloWorldPlugin";
$locale["Here you can override site-specific default values."] =
   "你可以在這裡覆寫掉站台預設的值.";
$locale["Hide %s:"] =
   "隱藏 %s:";
$locale["Hide or show LinkIcons (if supported by the current theme). Useful for text-only browsers or slow connections."] =
   "隱藏或顯示連結圖示 (如果目前佈景主題有支援). 只有在瀏覽器認為頻寬過慢的情況下被使用.";
$locale["History of all major and minor edits by %s to page %s."] =
   "所有被 %s 修改的主要和次要修訂歷程 - 頁面 %s.";
$locale["History of all major and minor modifications for any page edited by %s."] =
   "被 %s 修改的所有頁面的主要與次要變更歷程.";
$locale["History of changes."] =
   "變更的歷程.";
$locale["Hit statistics"] =
   "擊閱數統計";
$locale["Hits"] =
   "點擊";
$locale["Hits:"] =
   "點擊數:";
$locale["HomePage"] =
   "首頁";
$locale["HomePageAlias"] =
   "HomePageAlias";
$locale["HowToUseWiki"] =
   "HowToUseWiki";
$locale["I'm just doing minor edits. Please divert the usual logging to %s instead."] =
   "我正在做次要編輯. 請轉移常用日誌到替代的 %s.";
$locale["I'm sorry, there is no such page as %s."] =
   "抱歉,這裡沒有任何被命名為 %s 的頁面.";
$locale["I'm sorry.  Version %d of %s is not in the database."] =
   "抱歉, 版本是 %d 的 %s 不在資料庫中.";
$locale["Image loaded from cache file: %s"] =
   "影像已從快取檔案: %s 載入";
$locale["Image saved to cache file: %s"] =
   "影像存於快取檔案: %s";
$locale["In the time since you started editing this page, another user has saved a new version of it."] =
   "從你上次修改這個頁面到現在的這段時間,已經有使用者儲存了較新的版本.";
$locale["Include an external web page within the body of a wiki page."] =
   "含括外部網頁到 wiki 頁面的內容中.";
$locale["Include recursively all linked pages starting at %s"] =
   "遞迴地含括所有從 %s 開始有連結到的網頁.";
$locale["Include text from another wiki page."] =
   "從其他 wiki 頁面含括文字.";
$locale["IncludePage"] =
   "含括頁面";
$locale["IncludePagePlugin"] =
   "IncludePagePlugin";
$locale["IncludeSiteMap"] =
   "IncludeSiteMap";
$locale["Included from %s"] =
   "從 %s 含括進來";
$locale["Included from %s:"] =
   "已從 %s 含括:";
$locale["Includes the content of all SubPages of the current page."] =
   "含括目前頁面所有子頁面的內容.";
$locale["Index"] =
   "索引";
$locale["Info"] =
   "Info";
$locale["Inline images"] =
   "Inline 圖片";
$locale["Insufficient permissions."] =
   "權限不足.";
$locale["InterWiki"] =
   "InterWiki";
$locale["InterWiki Address"] =
   "InterWiki 位址";
$locale["InterWikiMap"] =
   "InterWikiMap";
$locale["InterWikiSearch"] =
   "InterWikiSearch";
$locale["Invalid chmod string"] =
   "錯誤的 chmod 字串";
$locale["Invalid color: %s"] =
   "錯誤的顏色值: %s";
$locale["Invalid password or userid."] =
   "錯誤的密碼或使用者帳號.";
$locale["JabberPresence"] =
   "JabberPresence";
$locale["Keep up to %d major edits, but keep them no longer than %d days."] =
   "保持 %d 份主要編輯,但不超過 %d 天.";
$locale["Language"] =
   "語言";
$locale["Last"] =
   "最後";
$locale["Last Author"] =
   "最後一位修改的作者";
$locale["Last Modified"] =
   "最後修改";
$locale["Last Summary"] =
   "最後摘要";
$locale["LatestSnapshot"] =
   "最新快照";
$locale["Layout tables using a very rich markup style."] =
   "使用豐富標記風格進行佈局的表格.";
$locale["Layout tables using the old markup style."] =
   "使用舊標記風格佈局的表格.";
$locale["Leading %s not allowed"] =
   "前面的 %s 是不被允許的";
$locale["Legend"] =
   "圖例";
$locale["LikePages"] =
   "LikePages";
$locale["LinkIcons"] =
   "LinkIcons";
$locale["List PageHistory for %s"] =
   "列出 PageHistory (頁面歷程) - %s";
$locale["List all page revisions edited by one user with diff links, or show a PageHistory-like list of a single page for only one user."] =
   "列出所有被使用者編輯的頁面修訂,並帶有差異連結,或顯示像是頁面歷程的單一頁面列表.";
$locale["List all pages in this wiki."] =
   "在此 wiki 列出所有頁面.";
$locale["List all pages which link to %s."] =
   "列出所有連結到 %s 的頁面.";
$locale["List all pages."] =
   "列出所有頁面.";
$locale["List page names which share an initial or final title word with '%s'."] =
   "列出分享為 '%s' 開頭或結尾的標題字的頁面名稱";
$locale["List pages which are not linked to by any other page."] =
   "列出未被其他頁面連結到的頁面.";
$locale["List the most popular pages."] =
   "列出最受歡迎的頁面.";
$locale["List this page and all subpages"] =
   "列出所有頁面以及子頁面";
$locale["ListSubpages"] =
   "ListSubpages";
$locale["Lists referenced page names which do not exist yet."] =
   "列出還未存在的頁面名稱.";
$locale["Lists the names of all SubPages of the current page."] =
   "列出目前頁面的所有子頁面名稱.";
$locale["Load File"] =
   "載入檔案";
$locale["Loading '%s'"] =
   "載入 '%s'";
$locale["Loading InterWikiMap from external file %s."] =
   "從外部檔案 %s 載入 InterWikiMap";
$locale["Loading files"] =
   "載入檔案";
$locale["Loading up virgin wiki"] =
   "載入原始 wiki";
$locale["Lock Page"] =
   "鎖定頁面";
$locale["Lock page to enable link"] =
   "鎖定頁面以打開此連結";
$locale["Locked"] =
   "已鎖定";
$locale["Locking pages"] =
   "鎖定頁面";
$locale["Login"] =
   "登入";
$locale["MIME file %s"] =
   "MIME 檔案 %s";
$locale["MagicPhpWikiURLs"] =
   "MagicPhpWikiURLs";
$locale["Make use of the Google API"] =
   "Make use of the Google API";
$locale["Markup"] =
   "標記";
$locale["Markup cache purged!"] =
   "標記快取已經清除!";
$locale["Markup:"] =
   "標記";
$locale["Merge Edit"] =
   "合併編輯";
$locale["Merge and Edit: %s"] =
   "合併並離開: %s";
$locale["Method '%s' not implemented in this GROUP_METHOD %s"] =
   "方法 '%s' 未實作在 GROUP_METHOD %s";
$locale["Minor"] =
   "次要";
$locale["Minor Edit"] =
   "次要編輯";
$locale["Missing %s for %s"] =
   "遺失了 %s 的 %s";
$locale["Modern"] =
   "Modern";
$locale["Modified"] =
   "已變更";
$locale["Moniker"] =
   "名字";
$locale["MoreAboutMechanics"] =
   "MoreAboutMechanics";
$locale["MostPopular"] =
   "MostPopular";
$locale["Name"] =
   "名稱";
$locale["New comment."] =
   "新意見.";
$locale["New password"] =
   "新密碼";
$locale["New users may use an empty password."] =
   "新使用者可以使用空白密碼.";
$locale["NewMarkupTestPage"] =
   "NewMarkupTestPage";
$locale["Newer page:"] =
   "較新的頁面:";
$locale["Next"] =
   "下一個";
$locale["Next Month"] =
   "下個月";
$locale["No LDAP in this PHP version"] =
   "此版本的 PHP 無 LDAP";
$locale["No changes found"] =
   "沒發現任何變更";
$locale["No changes."] =
   "沒有變更.";
$locale["No or not enough GROUP_DB SQL statements defined"] =
   "沒有或缺少足夠的 GROUP_DB SQL 敘述定義";
$locale["No or unsupported GROUP_METHOD defined"] =
   "沒有或不支援的 GROUP_METHOD 定義.";
$locale["No other page links to %s yet."] =
   "沒有頁面連結到 %s.";
$locale["No page links to %s."] =
   "沒有頁面連結到 %s.";
$locale["No pagedata for %s"] =
   "無頁面資料 %s";
$locale["No pagename specified"] =
   "沒有指定頁面名稱";
$locale["No pages changed."] =
   "沒有頁面被變更.";
$locale["No pages renamed."] =
   "沒有頁面被更名";
$locale["No revisions found"] =
   "沒找到修訂";
$locale["No uploaded file to upload?"] =
   "沒有要上傳的檔案?";
$locale["No userid"] =
   "沒有此使用者帳號";
$locale["NoCache"] =
   "NoCache";
$locale["None"] =
   "無";
$locale["Not enough questions answered!"] =
   "沒有足夠的已回答問題!";
$locale["Note that many browsers will automatically adjust the width of the editing area so that it fills the browser window.  In this case, the width preference will be ignored."] =
   "注意:許多瀏覽器會自動調整編輯區域的寬度以填滿瀏覽視窗. 在這種情況下,寬度設定將會被忽略.";
$locale["Note, that user accounts with bouncing emails will be disabled."] =
   "注意, 使用者帳號的回信(bouncing emails)將被關閉.";
$locale["Note:"] =
   "注意:";
$locale["Okay"] =
   "Okay";
$locale["Old UserPage %s without stored password updated with empty password. Set a password in your UserPreferences."] =
   "Old UserPage %s without stored password updated with empty password. Set a password in your UserPreferences.";
$locale["OldMarkupTestPage"] =
   "OldMarkupTestPage";
$locale["OldStyleTable"] =
   "OldStyleTable";
$locale["OldStyleTablePlugin"] =
   "OldStyleTablePlugin";
$locale["Older page:"] =
   "較舊的頁面:";
$locale["One page links to %s:"] =
   "一個頁面連結到 %s:";
$locale["One page would link to %s:"] =
   "有個頁面可能連結到 %s:";
$locale["Oops! Revision %s of %s seems to have been deleted!"] =
   "Acck! 修訂 %s - %s 看來已經被刪除了!";
$locale["Original (1.2 or 1.0)"] =
   "原始 (1.2 或 1.0)";
$locale["Orphaned Pages in this wiki (%d total):"] =
   "在此 wiki 中所有遺漏的頁面 (共 %d):";
$locale["OrphanedPages"] =
   "OrphanedPages";
$locale["Other diffs:"] =
   "其他差異:";
$locale["Other version"] =
   "其他版本";
$locale["Our users created a total of %d pages."] =
   "這兒的使用者共建立了 %d 個頁面.";
$locale["Owner"] =
   "擁有者";
$locale["PHP syntax highlighting"] =
   "PHP 語法效果";
$locale["PHP was unable to create a new GD image stream. Read 'lib/plugin/text2png.php' for details."] =
   "PHP 無法建立新的 GD 影像流. 閱讀 lib/plugin/text2png.php 以取得更多資訊.";
$locale["Page %s not found."] =
   "未找到頁面 %s.";
$locale["Page Execution took %s seconds"] =
   "執行此頁面花了 %s 秒";
$locale["Page Locked"] =
   "頁面已被鎖定";
$locale["Page Name"] =
   "頁面名稱";
$locale["Page Type:"] =
   "頁面型態:";
$locale["Page Version:"] =
   "頁面版本";
$locale["Page names with prefix '%s'"] =
   "頁面名稱以 '%s' 開頭的";
$locale["Page names with suffix '%s'"] =
   "頁面名稱以 '%s' 結尾的";
$locale["Page now locked."] =
   "頁面已被鎖定.";
$locale["Page now unlocked."] =
   "頁面已被解鎖定.";
$locale["Page statistics"] =
   "頁面統計";
$locale["PageChange Notification Error: Couldn't send %s to %s"] =
   "PageChange 通知錯誤: 無法送 %s 給 %s";
$locale["PageChange Notification of %s sent to %s"] =
   "%s 的 PageChange 通知已送給 %s";
$locale["PageDump"] =
   "PageDump";
$locale["PageGroup"] =
   "PageGroup";
$locale["PageGroup for %s"] =
   "頁面群組 - %s";
$locale["PageGroupTest"] =
   "PageGroupTest";
$locale["PageHistory"] =
   "PageHistory";
$locale["PageHistory for %s"] =
   "頁面歷程 - %s";
$locale["PageInfo"] =
   "PageInfo";
$locale["PageTrail"] =
   "PageTrail";
$locale["PageTrail Plugin"] =
   "PageTrail Plugin";
$locale["Pagedata size: %d Kb"] =
   "頁面資料大小: %d Kb";
$locale["Password cannot be changed."] =
   "無法變更密碼.";
$locale["Password updated."] =
   "密碼已經更新.";
$locale["Password:"] =
   "密碼:";
$locale["Perform searches on InterWiki sites listed in InterWikiMap."] =
   "在列在 InterWikiMap 清單中的 InterWiki 站台進行搜尋.";
$locale["Permanently remove all selected pages."] =
   "永久移除選定的頁面.";
$locale["Permanently remove the selected files:"] =
   "永久移除選定的檔案:";
$locale["Permission"] =
   "權限";
$locale["Personal Auth Settings for '%s'"] =
   "'%s' 的個人認證設定.";
$locale["Personal language:"] =
   "個人語言:";
$locale["Personal theme:"] =
   "個人佈景主題:";
$locale["PgsrcTranslation"] =
   "PgsrcTranslation";
$locale["PhotoAlbum"] =
   "PhotoAlbum";
$locale["PhotoAlbumPlugin"] =
   "PhotoAlbumPlugin";
$locale["PhpHighlight"] =
   "PhpHighlight";
$locale["PhpHighlightPlugin"] =
   "PhpHighlightPlugin";
$locale["PhpWeather"] =
   "PhpWeather";
$locale["PhpWeatherPlugin"] =
   "PhpWeatherPlugin";
$locale["PhpWiki"] =
   "PhpWiki";
$locale["PhpWiki developers should manually inspect the downloaded file for nested markup before rewrapping with emacs and checking into CVS."] =
   "在以 emacs 重包裝與簽入之前,PhpWiki 開發者應會因為巢狀標記而手動審閱已下載的檔案.";
$locale["PhpWiki engine version"] =
   "PhpWiki 引擎版本";
$locale["PhpWikiAdministration"] =
   "PhpWikiAdministration";
$locale["PhpWikiAdministration/Chmod"] =
   "PhpWikiAdministration/Chmod";
$locale["PhpWikiAdministration/Remove"] =
   "PhpWikiAdministration/Remove";
$locale["PhpWikiAdministration/Rename"] =
   "PhpWikiAdministration/Rename";
$locale["PhpWikiAdministration/Replace"] =
   "PhpWikiAdministration/Replace";
$locale["PhpWikiDocumentation"] =
   "PhpWikiDocumentation";
$locale["PhpWikiPoll"] =
   "PhpWikiPoll";
$locale["Please check it through before saving."] =
   "在儲存之前請再檢查一次.";
$locale["Please contact your PhpWiki administrator for assistance."] =
   "請向你的 PhpWiki 管理者尋求協助.";
$locale["Please continue editing.  (You'll find your %s at the bottom of the page.)"] =
   "請繼續編輯. (你將在頁面的底部找到你的 %s.)";
$locale["Please use one of the downloadable versions rather than copying and pasting from the above preview."] =
   "請使用其中的可下載版本來代替在上面的預覽中複製與貼上.";
$locale["Plugin"] =
   "Plugin";
$locale["Plugin %s disabled."] =
   "Plugin %s 關閉.";
$locale["Plugin %s failed."] =
   "Plugin %s 失敗.";
$locale["PluginManager"] =
   "PluginManager";
$locale["Plugins"] =
   "Plugins";
$locale["PreferencesInfo"] =
   "PreferencesInfo";
$locale["PrevNext"] =
   "PrevNext";
$locale["Preview"] =
   "預覽";
$locale["Preview as backup format"] =
   "以備份格式預覽";
$locale["Preview as developer format"] =
   "以開發者格式預覽";
$locale["Preview only!  Changes not saved."] =
   "僅能預覽! 更動將不被儲存.";
$locale["Preview: Page dump of %s"] =
   "預覽: %s 的頁面傾印";
$locale["Previous"] =
   "上一個";
$locale["Previous Author"] =
   "上一次做此更動的作者";
$locale["Previous Major Revision"] =
   "上一次主要修訂";
$locale["Previous Month"] =
   "上個月";
$locale["Previous Revision"] =
   "上一次修訂";
$locale["Printer"] =
   "印表機";
$locale["Propagate new permissions to all subpages?"] =
   "要傳播新的權限到所有子頁面?   ";
$locale["Provides access to PhpWiki's lower level system information."] =
   "提供存取 PhpWiki 下層系統資訊.";
$locale["Purge HTML cache for this page. Regenerate from WikiMarkup when next accessed."] =
   "為此頁面清除 HTML 快取. 下次將重新由 WikiMarkup 產生.";
$locale["Purge Markup Cache"] =
   "清除標記快取";
$locale["PurgeHtmlCache"] =
   "PurgeHtmlCache";
$locale["Querying backend directly for '%s'"] =
   "為 '%s' 直接查詢後台";
$locale["RandomPage"] =
   "RandomPage";
$locale["Rate"] =
   "Rate";
$locale["Rate It"] =
   "評比";
$locale["Rate the topic of this page"] =
   "評比此頁面的主題";
$locale["RateIt"] =
   "RateIt";
$locale["Rated by %d users | Average rating %.1f stars"] =
   "被 %d 位使用者評比 | 平均評分為 %.1f";
$locale["Rating system. Store user ratings per page"] =
   "評比系統. 儲存每頁的使用者評比";
$locale["Raw HTML"] =
   "Raw HTML";
$locale["Raw HTML is disabled in this wiki."] =
   "Raw HTML 已經被關閉.";
$locale["RawHtmlPlugin"] =
   "RawHtmlPlugin";
$locale["RecentChanges"] =
   "RecentChanges";
$locale["RecentEdits"] =
   "RecentEdits";
$locale["RecentVisitors"] =
   "RecentVisitors";
$locale["Recursive redirect to self: '%s'"] =
   "遞迴重導向到自己: '%s'";
$locale["Recursively get BackLinks or links"] =
   "遞迴地取得 BackLinks 或連結";
$locale["Redirect"] =
   "重導向";
$locale["Redirect to an external url"] =
   "重導向到另一個外部 url";
$locale["RedirectTo"] =
   "RedirectTo";
$locale["RedirectToPlugin"] =
   "RedirectToPlugin";
$locale["Redirects to an external web site based on form input"] =
   "以表單輸入方式重導向到另外一個外部站台";
$locale["Redirects to another url or page."] =
   "重導向到另一個 url 或頁面.";
$locale["References"] =
   "偏好設定";
$locale["Registered Users"] =
   "已註冊的使用者";
$locale["Registered Users Online: "] =
   "已註冊的使用者在線上:";
$locale["Related Links"] =
   "相關連結";
$locale["ReleaseNotes"] =
   "ReleaseNotes";
$locale["Remove"] =
   "移除";
$locale["Remove Page"] =
   "移除頁面";
$locale["Remove selected pages"] =
   "移除選定頁面";
$locale["Remove this page"] =
   "移除此頁面";
$locale["Removed page '%s' successfully."] =
   "成功地移除頁面 '%s'.";
$locale["Removing pages"] =
   "移除頁面";
$locale["Rename"] =
   "更名";
$locale["Rename selected pages"] =
   "更名已選定的頁面";
$locale["Rename to"] =
   "更名為";
$locale["Renamed page '%s' to '%s'."] =
   "更名頁面 '%s' 為 '%s'.";
$locale["Replace: "] =
   "取代:";
$locale["Replaced '%s' with '%s' in page '%s'."] =
   "取代 '%s' 以 '%s' 在頁面 '%s'.";
$locale["Requires WikiAdmin privileges to edit."] =
   "需要 WikiAdmin 權限方能編輯.";
$locale["Reset"] =
   "重設";
$locale["Restore Anyway"] =
   "無論如何都回存";
$locale["Return to %s"] =
   "回到 %s";
$locale["Revision Not Found"] =
   "修訂未找到";
$locale["RichTable"] =
   "RichTable";
$locale["RichTablePlugin"] =
   "RichTablePlugin";
$locale["RssFeed"] =
   "RssFeed";
$locale["SandBox"] =
   "SandBox";
$locale["Save"] =
   "儲存";
$locale["Saved on:"] =
   "已存放在:";
$locale["Saved: %s"] =
   "已存於: %s";
$locale["Saving this page will overwrite the current version."] =
   "儲存此頁面將會覆寫掉目前版本.";
$locale["Score"] =
   "得分";
$locale["Search"] =
   "搜尋";
$locale["Search & Replace"] =
   "搜尋與取代";
$locale["Search and replace text in selected wiki pages."] =
   "在選定的頁面中搜尋並更換文字.";
$locale["Search for page titles similar to %s."] =
   "搜尋與 %s 相似的頁面標題";
$locale["Search the content of all pages in this wiki."] =
   "在此 wiki 所有頁面中搜尋內容.";
$locale["Search the titles of all pages in this wiki."] =
   "在此 wiki 的所有頁面搜尋標題.";
$locale["See %s"] =
   "參照 %s";
$locale["See %s tips for editing."] =
   "參照編輯時的 %s 小秘訣.";
$locale["See: %s"] =
   "參閱: %s";
$locale["Select"] =
   "選擇";
$locale["Select pages"] =
   "選擇頁面";
$locale["Select the pages to change:"] =
   "選擇頁面以進行更名:";
$locale["Select the pages to rename:"] =
   "選擇頁面以進行更名:";
$locale["Select the pages to search:"] =
   "選擇頁面以進行搜尋:";
$locale["Select: "] =
   "選擇";
$locale["Selected page '%s' passed to '%s'."] =
   "已選擇的頁面 '%s' 傳遞到 '%s'.";
$locale["Serialized file %s"] =
   "Serialized 到檔案 %s";
$locale["Set individual page permissions."] =
   "設定個別頁面的權限.";
$locale["SetAcl"] =
   "SetAcl";
$locale["Show all changes for:"] =
   "顯示所有變更:";
$locale["Show and add blogs for %s"] =
   "顯示並增加 blogs - %s";
$locale["Show and add comments for %s"] =
   "顯示並對 %s 發表意見";
$locale["Show changes for:"] =
   "顯示變更:";
$locale["Show extra page Info and statistics for %s."] =
   "顯示額外的頁面資訊與統計 - %s.";
$locale["Show minor edits for:"] =
   "顯示次要編輯:";
$locale["Show relative dates using 'Today' and 'Yesterday'"] =
   "使用'今天'和'昨天'來顯示相對日期.";
$locale["Show summary information of the current user sessions."] =
   "顯示目前使用者 session 的摘要資訊.";
$locale["Show translations of various words or pages"] =
   "顯示多個字或頁面的轉換";
$locale["Sign In"] =
   "簽入";
$locale["Sign Out"] =
   "簽出";
$locale["Sign in as:"] =
   "簽入為:";
$locale["Signed Users"] =
   "已簽入的使用者";
$locale["Simple RSS Feed aggregator Plugin"] =
   "簡單的 RSS Feed aggregator Plugin";
$locale["Simple Sample Plugin"] =
   "簡單的範例 Plugin";
$locale["Simple jabber presence plugin"] =
   "簡單的 jabber presence plugin";
$locale["Since you started the deletion process, someone has saved a new version of %s.  Please check to make sure you still want to permanently remove the page from the database."] =
   "從你開始刪除到現在,有人已經儲存了一份 %s 的較新版本. 請檢查以確定你仍想要從資料庫中永久刪除此頁面.";
$locale["SiteMap"] =
   "SiteMap";
$locale["Size"] =
   "大小";
$locale["Size:"] =
   "大小";
$locale["Skipping"] =
   "跳過";
$locale["Some of the changes could not automatically be combined.  Please look for sections beginning with '%s', and ending with '%s'.  You will need to edit those sections by hand before you click Save."] =
   "部份更動無法自動合併. 請搜尋以 '%s' 開頭並以 '%s' 結尾的部份.在儲存之前,你需要手動編輯這些部份.";
$locale["Someone has edited the page!"] =
   "有人編輯了此頁面!";
$locale["Sorry for the inconvenience."] =
   "抱歉造成你的不便.";
$locale["Sorry! You must wait at least 20 minutes until you can vote again!"] =
   "抱歉! 你必須等至少 20 分鐘才能在投票!";
$locale["Sorry, no dynamic DB Session support."] =
   "抱歉,無動態 DB Session 支援.";
$locale["Sorry, this version of PHP cannot create PNG image files."] =
   "抱歉, 這個版本的 PHP 無法建立 PNG 圖片檔.";
$locale["Sorry. Access Restrictions not yet implemented"] =
   "抱歉. 存取限制尚未被實作.";
$locale["Sort by %s"] =
   "以 %s 排序";
$locale["Sound Score"] =
   "音節得分";
$locale["Spelling Score"] =
   "拼字得分";
$locale["SqlResult"] =
   "SqlResult";
$locale["Statistics about %s."] =
   "關於 %s 的統計.";
$locale["Status:"] =
   "狀態:";
$locale["SteveWainstead"] =
   "SteveWainstead";
$locale["SubPages of %s:"] =
   "%s 的子頁面:";
$locale["Submit"] =
   "送出";
$locale["Submit country"] =
   "送出國家";
$locale["Submit location"] =
   "送出地區";
$locale["Subpage"] =
   "子頁面";
$locale["Summary"] =
   "摘要";
$locale["Supplanted on:"] =
   "代替為";
$locale["Supported languages"] =
   "已支援的語言";
$locale["Supported themes"] =
   "已支援的佈景主題";
$locale["Switch to detailed list"] =
   "切換到明細列表";
$locale["Switch to summary"] =
   "切換到摘要";
$locale["Synopsis"] =
   "概要";
$locale["System default:"] =
   "系統預設:";
$locale["SystemInfo"] =
   "SystemInfo";
$locale["SystemInfoPlugin"] =
   "SystemInfoPlugin";
$locale["TODO: Google can only translate from english and french. Find a translation service for %s to language %s"] =
   "TODO: Google 只能從英文與法文轉換. 為 %s 尋找轉換到語言 %s 的服務.";
$locale["Table Of Contents"] =
   "目錄";
$locale["Thank you for editing %s."] =
   "謝謝你編輯了 %s.";
$locale["Thanks for adding this translation!"] =
   "謝謝你增加此轉換!";
$locale["Thanks for participating!"] =
   "謝謝你的參與.";
$locale["The %d least popular pages of this wiki:"] =
   "本 wiki 前 %d 最不受歡迎頁面:";
$locale["The %d most popular pages of this wiki:"] =
   "本 wiki 前 %d 最受歡迎頁面:";
$locale["The %d most recent %s are listed below."] =
   "最近的 %d 筆列在下面 - 頁面 %s.";
$locale["The %d most recent %s during the past %s days are listed below."] =
   "最近的 %d 筆列在下面 - 頁面 %s - 在過去 %s 天以來.";
$locale["The %d most recent %s during the past day are listed below."] =
   "最近的 %d 筆列在下面 - 頁面 %s - 在過去一天以來.";
$locale["The %d oldest %s are listed below."] =
   "最舊的 %d 筆列在下面 - 頁面 %s.";
$locale["The %d oldest %s during the past %s days are listed below."] =
   "最舊的 %d 筆列在下面 - 頁面 %s - 在過去 %s 天以來.";
$locale["The %d oldest %s during the past day are listed below."] =
   "最舊的 %d 筆列在下面 - 頁面 %s - 在過去一天以來.";
$locale["The %s subpage enables simple weblogging."] =
   "%s 子頁面啟動簡易 weblogging";
$locale["The ICAO '%s' wasn't recognized."] =
   "ICAO '%s' 無法被認可.";
$locale["The PhpWeather plugin provides weather reports from the Internet."] =
   "PhpWeather plugin 由網路取得資訊並提供天氣報告";
$locale["The PhpWiki access log file"] =
   "PhpWiki 存取日誌檔案";
$locale["The PhpWiki programming team"] =
   "PhpWiki 開發團隊";
$locale["The crypt function is not available in this version of PHP."] =
   "此版本的 PHP 沒有 crypt 函數.";
$locale["The current page has no subpages defined."] =
   "目前頁面沒有定義任何子頁面.";
$locale["The current time at the server is %s."] =
   "目前在伺服器上的時間是 %s.";
$locale["The length of the stored password is shorter than the system policy allows. Sorry, you cannot login.\n You have to ask the System Administrator to reset your password."] =
   "密碼長度小於系統原則所允許的長度. 抱歉,你無法登入. \n 你必須詢問系統管理者以重設密碼.";
$locale["The most recent %s during the past %s days are listed below."] =
   "最新的紀錄已經列在下面 - 頁面 %s - 在過去 %s 天以來.";
$locale["The most recent %s during the past day are listed below."] =
   "最新的紀錄已經列在下面 - 頁面 %s - 在過去一天以來.";
$locale["The result of this poll so far:"] =
   "這次投票的結果是這樣:";
$locale["The session.save_path directory"] =
   "session.save_path 目錄";
$locale["The wordwrap of the preview doesn't take nested markup or list indentation into consideration!"] =
   "預覽的自動換行無法處理巢狀標記或縮排列出.";
$locale["Theme"] =
   "佈景主題";
$locale["There is no image creation data available to id '%s'. Please reload referring page."] =
   "沒有id '%s' 可用的圖片創作資料. 請重新載入參照頁面.";
$locale["These page titles match fuzzy with '%s'"] =
   "這些頁面標題與 '%s' 有點接近";
$locale["These pages share an initial or final title word with '%s'"] =
   "這些頁面分享為 '%s' 開頭或結尾的標題字.";
$locale["This internal action page cannot viewed."] =
   "內部動作頁面無法瀏覽.";
$locale["This is a minor change."] =
   "這是次要變更.";
$locale["This page already exists"] =
   "此頁面已經存在";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "此頁面已經被管理者鎖定,並且無法編輯.";
$locale["This page has been locked by the administrator so your changes can not be saved."] =
   "此頁面已被管理者鎖定,所以你的更動無法儲存.";
$locale["This plugin is currently under development and does not work!"] =
   "此 plugin 正在開發還不能運作!";
$locale["Time Zone"] =
   "時區";
$locale["Title Search"] =
   "標題搜尋";
$locale["Title search results for '%s'"] =
   "以 '%s' 進行標題搜尋的結果";
$locale["TitleSearch"] =
   "標題搜索";
$locale["Today"] =
   "今天";
$locale["Top & bottom toolbars"] =
   "Top & bottom 工具列";
$locale["Total %d plugins: "] =
   "共有 %d 個 plugin:";
$locale["Total of %d languages: "] =
   "共有 %d 種語言:";
$locale["Total of %d themes: "] =
   "共有 %d 組佈景主題: ";
$locale["Transclude"] =
   "Transclude";
$locale["TranscludePlugin"] =
   "TranscludePlugin";
$locale["Transcluded from %s"] =
   "Transcluded 從 %s";
$locale["Transcluded page"] =
   "Transcluded 頁面";
$locale["Translate"] =
   "轉換";
$locale["Translate %s to %s in %s"] =
   "轉換 %s 到 %s 在 %s";
$locale["Translate '%s' to '%s' in *%s*"] =
   "轉換 '%s' 到 '%s' 在 *%s*";
$locale["TranslateText"] =
   "TranslateText";
$locale["Translation Error!"] =
   "轉換錯誤!";
$locale["Type it again"] =
   "再輸入一次:";
$locale["Unable to connect to IMAP server "] =
   "無法連結到 IMAP 伺服器";
$locale["Unable to connect to LDAP server %s"] =
   "無法連結到 LDAP 伺服器 %s";
$locale["Unable to open directory '%s' for reading"] =
   "無法開啟目錄 '%s' 進行讀取";
$locale["Undefined method %s for special group %s"] =
   "未定義的 %s, 對特別的群組 %s";
$locale["Unexpected EOF in zip file"] =
   "zip 檔案中存有不被期待的 EOF.";
$locale["UnfoldSubpages"] =
   "UnfoldSubpages";
$locale["UnfoldSubpagesPlugin"] =
   "UnfoldSubpagesPlugin";
$locale["Unlock Page"] =
   "解除鎖定頁面";
$locale["Unlocking pages"] =
   "解除鎖定頁面";
$locale["Unsupported ACL access type %s ignored."] =
   "忽略不支援的 ACL 存取型態 %s.";
$locale["Up"] =
   "上";
$locale["UpLoad"] =
   "UpLoad";
$locale["Update Preferences"] =
   "更新偏好設定";
$locale["Upgrade disabled: user != isAdmin"] =
   "禁止升級: user != isAdmin";
$locale["Upgrading this PhpWiki"] =
   "升級 PhpWiki";
$locale["Upload"] =
   "上傳";
$locale["Upload files to the local InterWiki Upload:<filename>"] =
   "上傳檔案到本地 InterWiki. Upload:<filename>";
$locale["Uploading %s"] =
   "上傳中 %s";
$locale["Uploading zip dumps"] =
   "上傳 zip dumps";
$locale["Use old markup"] =
   "使用舊標記";
$locale["User page"] =
   "使用者頁面";
$locale["User preferences for user '%s':"] =
   "使用者 '%s' 的偏好設定:";
$locale["User statistics"] =
   "使用者統計";
$locale["User: %s"] =
   "User: %s";
$locale["UserId"] =
   "帳號";
$locale["UserId:"] =
   "帳號:";
$locale["UserPreferences"] =
   "UserPreferences";
$locale["Users will not be able to sign in."] =
   "使用者將無法簽入.";
$locale["Using directory '%s'"] =
   "使用目錄 '%s'";
$locale["Verification Status"] =
   "確認狀態";
$locale["Verify the current action"] =
   "確認目前動作";
$locale["Version"] =
   "版本";
$locale["Version %d"] =
   "版本 %d";
$locale["Version %s"] =
   "版本 %s";
$locale["Versions are identical"] =
   "版本相同";
$locale["View Source"] =
   "查看源碼";
$locale["View Source: %s"] =
   "查看源碼: %s";
$locale["View the current version"] =
   "查看目前版本";
$locale["View this page and all subpages"] =
   "查看此頁面以及所有子頁面";
$locale["Viewing redirecting page."] =
   "查看重導向的頁面.";
$locale["Viewing the source of pages"] =
   "查看頁面源碼";
$locale["Visited pages on this wiki, ordered by popularity:"] =
   "在此 wiki 已被參訪頁面, 以受歡迎程度排序:";
$locale["Visualizes the Wiki structure in a graph using the 'dot' commandline tool from graphviz."] =
   "從 graphviz 使用 'dot' 命令列工具以圖形視覺化 Wiki 結構.";
$locale["W"] =
   "寬";
$locale["WabiSabi"] =
   "WabiSabi";
$locale["WantedPages"] =
   "WantedPages";
$locale["Warning:"] =
   "警告:";
$locale["Warning: The search string cannot be empty!"] =
   "警告: 搜尋字串不能是空白!";
$locale["Warning: You are editing an old revision."] =
   "警告: 你正在編輯較舊的修訂.";
$locale["We have a total of %d registered users."] =
   "共有 %d 位已註冊的使用者.";
$locale["White space converted to single space"] =
   "空白空格轉換為單一空格";
$locale["Who Is Online"] =
   "誰在線上";
$locale["Who is online"] =
   "誰在線上";
$locale["WhoIsOnline"] =
   "WhoIsOnline";
$locale["Width"] =
   "寬度";
$locale["Wiki Name"] =
   "Wiki 名稱";
$locale["WikiAdminChmod"] =
   "WikiAdminChmod";
$locale["WikiAdminRemove"] =
   "WikiAdminRemove";
$locale["WikiAdminRename"] =
   "WikiAdminRename";
$locale["WikiAdminSearchReplace"] =
   "WikiAdminSearchReplace";
$locale["WikiAdminSearchReplace %s by %s"] =
   "WikiAdminSearchReplace %s 被 %s";
$locale["WikiAdminSelect"] =
   "WikiAdminSelect";
$locale["WikiAdminSetAcl"] =
   "WikiAdminSetAcl";
$locale["WikiAdminUtils"] =
   "WikiAdminUtils";
$locale["WikiBlog"] =
   "WikiBlog";
$locale["WikiBlogPlugin"] =
   "WikiBlogPlugin";
$locale["WikiDB::renamePage() not yet implemented for this backend"] =
   "後台的 WikiDB::renamePage() 還沒實作出來.";
$locale["WikiForm"] =
   "WikiForm";
$locale["WikiForm: %s: unknown action"] =
   "WikiForm: %s: 未知的動作";
$locale["WikiPlugin"] =
   "WikiPlugin";
$locale["WikiPoll"] =
   "WikiPoll";
$locale["WikiWikiWeb"] =
   "WikiWikiWeb";
$locale["Wikiname regexp"] =
   "Wikiname regexp";
$locale["With the current offset, this would be reported as %s."] =
   "以目前時差,這將被顯示為 %s.";
$locale["World"] =
   "World";
$locale["Wrong password. Try again."] =
   "錯誤的密碼.再試一次.";
$locale["XML-RPC access"] =
   "XML-RPC 存取";
$locale["Yes"] =
   "是";
$locale["You are signed but not authenticated as %s. "] =
   "你已經簽入但並未認證為 %s.";
$locale["You are viewing an old revision of this page."] =
   "你正在查看此頁面的較舊修訂.";
$locale["You can only use it via the _WikiTranslation plugin."] =
   "你只能透過 _WikiTranslation plugin 使用.";
$locale["You can personalize various settings in %s."] =
   "你可以在 %s 自訂多種個人化設定.";
$locale["You have not made any changes so no new version has been saved."] =
   "你沒有做任何更動,所以沒有存入任何新版本.";
$locale["You may sign in using any [WikiWord|AddingPages] as a user id. (Any characters in %s etc. may be used too). The user id will be used as a link in RecentChanges to your home page."] =
   "在使用任何 [WikiWord|AddingPages] 前必須先以你的帳號簽入. (%s 等.  或許也已經被其他人使用了). 帳號將會在近期更動中被用來作為連到你首頁的連結.";
$locale["You must be an administrator to %s."] =
   "你必須是一個管理者才能 %s.";
$locale["You must be an administrator to use this plugin."] =
   "你必須是管理者才能使用此 plugin.";
$locale["You must log in to %s."] =
   "你必須登入才能 %s.";
$locale["You must sign in to %s."] =
   "你必須簽入才能 %s.";
$locale["You must specify a directory to dump to"] =
   "你必須指定目錄以進行傾印";
$locale["Your E-Mail:"] =
   "你的 E-Mail:";
$locale["Your browser should have redirected you to %s."] =
   "你的瀏覽器應該會重導向到 %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "感謝你的小心關注.";
$locale["Your changes can not be saved as they are, since doing so would overwrite the other author's changes. So, your changes and those of the other author have been combined. The result is shown below."] =
   "無法儲存你所變更的部份,在你編輯的這段時間,已經有其他作者變更了.所以你所變更的部份已經和其他作者變更的部份合併.結果顯示在下面.";
$locale["Your home page has not been created yet so your preferences cannot not be saved."] =
   "你的首頁還未被建立,所以你的偏好設定無法儲存.";
$locale["Your home page is locked so your preferences cannot not be saved."] =
   "你的首頁已經被鎖定,所以你的偏好設定無法被儲存.";
$locale["Your rating was %.1f"] =
   "你的評比是 %.1f";
$locale["Your translated text doesn't yet appear in this %s, but the Administrator will pick it up and add to the installation."] =
   "你的轉換文字不存在於 %s, 但管理者將會取用並加到安裝中.";
$locale["Your translated text is either empty or equal to the untranslated text. Please try again."] =
   "你的轉換文字是空白或等於未轉換的文字. 請再試一次.";
$locale["Your translation is stored in %s"] =
   "你的轉換存放在 %s";
$locale["Your version"] =
   "你的版本";
$locale["[%d] See [%s]"] =
   "[%d] 參閱 [%s]";
$locale["_WikiTranslation"] =
   "_WikiTranslation";
$locale["access this wiki via XML-RPC"] =
   "透過 XML-RPC 存取此 wiki";
$locale["argument '%s' not declared by plugin"] =
   "引數 '%s' 沒有被 plugin 宣告";
$locale["by"] =
   "被";
$locale["by %s"] =
   "被 %s";
$locale["cached pagedata:"] =
   "已置於快取的頁面資料:";
$locale["cached versiondata:"] =
   "已快取的版本資料:";
$locale["chmod page '%s' to '%s'."] =
   "改變頁面 '%s' 權限為 '%s'.";
$locale["compare revisions"] =
   "比較修訂";
$locale["couldn't open file '%s' for writing"] =
   "無法寫入到 '%s'.";
$locale["create this page"] =
   "建立此頁面";
$locale["current version"] =
   "目前版本";
$locale["days"] =
   "天";
$locale["default page permission"] =
   "預設頁面權限";
$locale["diff"] =
   "差異";
$locale["diff this page"] =
   "比對此頁面";
$locale["download a zip dump from this wiki"] =
   "從此 wiki 下載 zip dump";
$locale["dump html pages"] =
   "傾印 html 頁面";
$locale["dump serial pages"] =
   "傾印連續頁面";
$locale["edit area"] =
   "編輯區域";
$locale["edit this page"] =
   "編輯此頁面";
$locale["edits"] =
   "編輯";
$locale["from"] =
   "從";
$locale["from %s"] =
   "從 %s";
$locale["has edit conflicts - overwriting anyway"] =
   "編輯衝突 - 無論如何都覆寫";
$locale["has edit conflicts - skipped"] =
   "編輯衝突 - 跳過";
$locale["home page"] =
   "首頁";
$locale["invidual page permission"] =
   "個別頁面權限";
$locale["load files into this wiki"] =
   "載入檔案到此 wiki";
$locale["lock this page"] =
   "鎖定此頁面";
$locale["locked"] =
   "被鎖定";
$locale["major edits"] =
   "主要編輯";
$locale["max: %d"] =
   "最大: %d";
$locale["mean: %2.3f"] =
   "表示: %2.3f";
$locale["median: %d"] =
   "median: %d";
$locale["minor"] =
   "次要";
$locale["minor edit"] =
   "次要編輯";
$locale["minor edits"] =
   "次要編輯";
$locale["n/a"] =
   "n/a";
$locale["no cache used"] =
   "沒有快取被使用";
$locale["no page specified"] =
   "沒有指定頁面";
$locale["not yet"] =
   "尚未";
$locale["only %d pages displayed"] =
   "只有 %d 個頁面顯示出來";
$locale["page permission inherited from %s"] =
   "由 %s 繼承而來的頁面";
$locale["plain file %s"] =
   "一般檔案 %s";
$locale["predecessor to the previous major change"] =
   "上次主要變更的原始文件";
$locale["previous revision"] =
   "上一次修訂";
$locale["recursive inclusion of page %s"] =
   "遞迴含括頁面 %s";
$locale["recursive inclusion of page %s ignored"] =
   "忽略頁面 %s 的遞迴含括";
$locale["recursive inclusion of url %s"] =
   "遞迴含括 url %s";
$locale["remove this page"] =
   "移除此頁面";
$locale["renamed from %s"] =
   "從 %s 更名";
$locale["revision by previous author"] =
   "上位作者的修訂";
$locale["saved as %s"] =
   "存為 %s";
$locale["stddev: %2.3f"] =
   "stddev: %2.3f";
$locale["the file '%s'"] =
   "檔案 '%s'";
$locale["to"] =
   "到";
$locale["today"] =
   "今天";
$locale["too long"] =
   "太長";
$locale["total hits: %d"] =
   "總擊閱數: %d";
$locale["trailing cruft in plugin args: '%s'"] =
   "trailing cruft in plugin args: '%s'";
$locale["unknown argument '%s' to SystemInfo"] =
   "SystemInfo 未知的引數 '%s'";
$locale["unlock this page"] =
   "解除鎖定此頁面";
$locale["upload a zip dump"] =
   "上傳 zip 傾印";
$locale["uploaded %s"] =
   "已上傳 %s";
$locale["use this plugin"] =
   "使用此 plugin";
$locale["verify the current action"] =
   "確認目前動作";
$locale["version %d"] =
   "版本 %d";
$locale["version %s"] =
   "版本 %s";
$locale["view the source of this page"] =
   "查看此頁面源碼";
$locale["view this page"] =
   "查看此頁面";
$locale["yesterday"] =
   "昨天";

?>
